# eric7.MultiProject.MultiProjectFile

Module implementing a class representing the multi project JSON file.

### Global Attributes

MultiProject

### Classes

MultiProjectFile | Class representing the multi project JSON file.

### Functions

None

## MultiProjectFile

Class representing the multi project JSON file.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

MultiProjectFile | Constructor
readFile | Public method to read the multi project data from a multi project JSON file.
writeFile | Public method to write the multi project data to a multi project JSON file.

### Static Methods

None

#### MultiProjectFile (Constructor)

MultiProjectFile(multiProject: MultiProject, parent: QObject = None)

Constructor

multiProject (MultiProject)
  reference to the multi project object
parent (QObject (optional))
  reference to the parent object (defaults to None)

#### MultiProjectFile.readFile

readFile(filename: str)

Public method to read the multi project data from a multi project JSON file.

filename (str)
  name of the multi project file

Return:
  flag indicating a successful read

Return Type:
  bool

#### MultiProjectFile.writeFile

writeFile(filename: str)

Public method to write the multi project data to a multi project JSON file.

filename (str)
  name of the multi project file

Return:
  flag indicating a successful write

Return Type:
  bool

Up